pub(crate) fn report(
lint_name: &str,
lint_res: &Result<LintFnSuccess, LintFnError>,
elapsed: Duration,
)Expand description
Format and print the result of a completed lint execution.
pub(crate) fn report(
lint_name: &str,
lint_res: &Result<LintFnSuccess, LintFnError>,
elapsed: Duration,
)Format and print the result of a completed lint execution.