pub(crate) fn run_and_report(
lint_name: &str,
path: &Path,
run: fn(&Path) -> LintFnResult,
) -> LintFnResultExpand description
Run a single lint, measure its duration, and report immediately.
pub(crate) fn run_and_report(
lint_name: &str,
path: &Path,
run: fn(&Path) -> LintFnResult,
) -> LintFnResultRun a single lint, measure its duration, and report immediately.