pub(crate) struct LintFnResult(pub(crate) Result<LintFnSuccess, LintFnError>);Expand description
Newtype wrapper around Result<LintFnSuccess, LintFnError>.
Tuple Fields
0: Result<LintFnSuccess, LintFnError>Methods from Deref<Target = Result<LintFnSuccess, LintFnError>>
1.0.0 · Sourcepub fn as_ref(&self) -> Result<&T, &E>
pub fn as_ref(&self) -> Result<&T, &E>
Converts from &Result<T, E> to Result<&T, &E>.
Produces a new Result, containing a reference
into the original, leaving the original in place.
Examples
let x: Result<u32, &str> = Ok(2);
assert_eq!(x.as_ref(), Ok(&2));
let x: Result<u32, &str> = Err("Error");
assert_eq!(x.as_ref(), Err(&"Error"));1.47.0 · Sourcepub fn as_deref(&self) -> Result<&<T as Deref>::Target, &E>where
T: Deref,
pub fn as_deref(&self) -> Result<&<T as Deref>::Target, &E>where
T: Deref,
Converts from Result<T, E> (or &Result<T, E>) to Result<&<T as Deref>::Target, &E>.
Coerces the Ok variant of the original Result via Deref
and returns the new Result.
Examples
let x: Result<String, u32> = Ok("hello".to_string());
let y: Result<&str, &u32> = Ok("hello");
assert_eq!(x.as_deref(), y);
let x: Result<String, u32> = Err(42);
let y: Result<&str, &u32> = Err(&42);
assert_eq!(x.as_deref(), y);1.0.0 · Sourcepub fn iter(&self) -> Iter<'_, T>
pub fn iter(&self) -> Iter<'_, T>
Returns an iterator over the possibly contained value.
The iterator yields one value if the result is Result::Ok, otherwise none.
Examples
let x: Result<u32, &str> = Ok(7);
assert_eq!(x.iter().next(), Some(&7));
let x: Result<u32, &str> = Err("nothing!");
assert_eq!(x.iter().next(), None);Trait Implementations
Sourceimpl Deref for LintFnResult
impl Deref for LintFnResult
Sourcetype Target = Result<LintFnSuccess, LintFnError>
type Target = Result<LintFnSuccess, LintFnError>
The resulting type after dereferencing.
Sourceimpl From<Result<LintFnSuccess, LintFnError>> for LintFnResult
impl From<Result<LintFnSuccess, LintFnError>> for LintFnResult
Sourcefn from(value: Result<LintFnSuccess, LintFnError>) -> Self
fn from(value: Result<LintFnSuccess, LintFnError>) -> Self
Converts to this type from the input type.
Sourceimpl From<RmFilesOutcome> for LintFnResult
Converts RmFilesOutcome into LintFnResult.
impl From<RmFilesOutcome> for LintFnResult
Converts RmFilesOutcome into LintFnResult.
Sourcefn from(value: RmFilesOutcome) -> Self
fn from(value: RmFilesOutcome) -> Self
Converts to this type from the input type.